@@ -18,7 +18,7 @@ module RuboCop
         MSG = 'Use `reverse_each` instead of `reverse.each`.'
         UNDERSCORE = '_'
 
-        def_node_matcher :reverse_each?, <<-MATCHER
+        def_node_matcher :reverse_each?, <<~MATCHER
           (send $(send _ :reverse) :each)
         MATCHER
 
@@ -34,7 +34,8 @@ module RuboCop
         end
 
         def autocorrect(node)
-          ->(corrector) { corrector.replace(node.loc.dot, UNDERSCORE) }
+          range = range_between(node.loc.dot.begin_pos, node.loc.selector.begin_pos)
+          ->(corrector) { corrector.replace(range, UNDERSCORE) }
         end
       end
     end
