@@ -1,10 +1,18 @@
 # frozen_string_literal: true
 
+require_relative 'mixin/regexp_metacharacter'
+require_relative 'mixin/sort_block'
+
+require_relative 'performance/ancestors_include'
+require_relative 'performance/big_decimal_with_numeric_argument'
+require_relative 'performance/bind_call'
 require_relative 'performance/caller'
 require_relative 'performance/case_when_splat'
 require_relative 'performance/casecmp'
 require_relative 'performance/compare_with_block'
 require_relative 'performance/count'
+require_relative 'performance/delete_prefix'
+require_relative 'performance/delete_suffix'
 require_relative 'performance/detect'
 require_relative 'performance/double_start_end_with'
 require_relative 'performance/end_with'
@@ -13,13 +21,20 @@ require_relative 'performance/flat_map'
 require_relative 'performance/inefficient_hash_search'
 require_relative 'performance/open_struct'
 require_relative 'performance/range_include'
+require_relative 'performance/io_readlines'
 require_relative 'performance/redundant_block_call'
 require_relative 'performance/redundant_match'
 require_relative 'performance/redundant_merge'
+require_relative 'performance/redundant_sort_block'
+require_relative 'performance/redundant_string_chars'
 require_relative 'performance/regexp_match'
 require_relative 'performance/reverse_each'
+require_relative 'performance/reverse_first'
 require_relative 'performance/size'
+require_relative 'performance/sort_reverse'
+require_relative 'performance/squeeze'
 require_relative 'performance/start_with'
+require_relative 'performance/string_include'
 require_relative 'performance/string_replacement'
 require_relative 'performance/times_map'
 require_relative 'performance/unfreeze_string'
